#!/usr/bin/env bash

if [[ -z $1 || -z $2 ]]; then
    echo; echo "Usage: $0 <site.env> <query_file>";
    echo; echo;
    exit 1;
fi;

# Split site and environment to support conditional $ENV checking
SITE_NAME=${1%.*};
# echo "SITE_NAME: $SITE_NAME";
ENV=${1##*.};
# echo "ENV: $ENV";

# Wake site  (only if [[ $ENV == 'live' ]] if you have no sandboxes?)
terminus env:wake $SITE_NAME.$ENV;

# BACKUP FRESHNESS SCRIPT: https://gist.github.com/weaver299/46257300e53fe50b2a0b929ab721860e

# # Check if backup is "fresh" "enough"... (only if [[ $ENV == 'live' ]] maybe?)
if [[ $QUERY_ALL_GENERATE_BACKUPS -gt 0 ]]; then
  >&2 echo "Check backup freshness.."
  ./backup_fresh.sh $SITE_NAME.$ENV;
  BACKUP_FRESH=$?; # capture exit code

  if [[ $BACKUP_FRESH -gt 0 ]]; then
    # 0 means "fresh enough", else the script returns the age in seconds
    >&2 echo "Creating a fresh backup ...";
    # echo "terminus backup:create $SITE_NAME.$ENV --keep-for=30 --element=db";
    terminus backup:create $SITE_NAME.$ENV --keep-for=30 --element=db;
  fi
fi

# Get 'mysql' command from terminus
MYSQL_CMD=$(terminus connection:info --fields=mysql_command --format=string $SITE_NAME.$ENV);

# Pipe our query file into it
QUERY_CMD="cat $2 | $MYSQL_CMD";

# Suppress password on command line warning
QUERY_CMD="$QUERY_CMD 2>&1 | grep -vi 'using a password on the command line'";

# Remove field headers from query output
QUERY_CMD="$QUERY_CMD | tail +2";

# Run it
eval $QUERY_CMD;
